@@ -26,8 +26,7 @@
 #include "adblock-pattern.h"
 #include "ephy-file-helpers.h"
 
-#include <epiphany/ephy-adblock-manager.h>
-#include <epiphany/ephy-embed-shell.h>
+#include <epiphany/epiphany.h>
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
@@ -337,8 +336,8 @@ adblock_ui_populate_store (InfoPage *page, AdblockPatternType type)
 
 	patterns = g_hash_table_new_full (g_str_hash,
 					  g_str_equal,
-					  g_free,
-					  g_free);
+					  (GDestroyNotify)g_free,
+					  (GDestroyNotify)g_regex_unref);
 
 	adblock_pattern_load (patterns, type);
 
@@ -388,7 +387,7 @@ adblock_ui_constructor (GType type,
 
 	ephy_dialog_construct (EPHY_DIALOG (edialog),
 			properties,
-			SHARE_DIR "/glade/adblock.glade",
+			SHARE_DIR "/glade/adblock.ui",
 			"adblock-ui",
 			GETTEXT_PACKAGE);
 
